EvmLlvmBuilder

Struct EvmLlvmBuilder 

pub struct EvmLlvmBuilder<'a> {
    pub(crate) backend: &'a mut EvmLlvmBackend,
    pub(crate) function: FunctionValue<'static>,
    pub(crate) debug_scope: Option<DISubprogram<'static>>,
}
The LLVM-based EVM bytecode compiler function builder.

Fields

backend: &'a mut EvmLlvmBackendfunction: FunctionValue<'static>debug_scope: Option<DISubprogram<'static>>

Implementations

Source

impl EvmLlvmBuilder<'_>

pub(crate) fn extract_value( &mut self, value: BasicValueEnum<'static>, index: u32, name: &str, ) -> BasicValueEnum<'static>

pub(crate) fn memcpy_inner( &mut self, dst: BasicValueEnum<'static>, src: BasicValueEnum<'static>, len: BasicValueEnum<'static>, inline: bool, )

pub(crate) fn call_overflow_function( &mut self, name: &str, lhs: BasicValueEnum<'static>, rhs: BasicValueEnum<'static>, ) -> (BasicValueEnum<'static>, BasicValueEnum<'static>)

pub(crate) fn get_overflow_function( &mut self, name: &str, ty: BasicTypeEnum<'static>, ) -> FunctionValue<'static>

pub(crate) fn get_sat_function( &mut self, name: &str, ty: BasicTypeEnum<'static>, ) -> FunctionValue<'static>

pub(crate) fn get_or_add_function( &mut self, name: &str, mk_ty: impl FnOnce(&mut Self) -> FunctionType<'static>, ) -> FunctionValue<'static>

pub(crate) fn set_branch_weights( &self, inst: InstructionValue<'static>, weights: impl IntoIterator<Item = u32>, )

pub(crate) fn assume_inner( &mut self, cond: BasicValueEnum<'static>, ) -> CallSiteValue<'static>

Methods from Deref<Target = EvmLlvmBackend>

pub fn cx(&self) -> &Context

Returns the LLVM context.

pub(crate) fn module(&self) -> &Module<'static>

pub(crate) fn ensure_orc(&mut self) -> Result<&mut OrcJitState>

pub(crate) fn fn_type( &self, ret: Option<BasicTypeEnum<'static>>, params: &[BasicTypeEnum<'static>], ) -> FunctionType<'static>

pub(crate) fn name<'a>(&self, name: &'a str) -> &'a str

Returns the given name if IR output is being dumped, otherwise an empty string. LLVM skips internal name processing for empty names, avoiding overhead when names are not needed for readability.

pub(crate) fn id_to_name(&self, id: u32) -> &str

pub(crate) fn ensure_di_state(&mut self)

Lazily initializes the debug info builder and compile unit for the module.

pub(crate) fn commit_staged_module(&mut self) -> Result<()>

Commits the current staging module to the ORC JIT if there are pending functions.

pub(crate) fn reset_jit(&mut self) -> Result<()>

Clears all code from this compiler’s JITDylib, freeing JIT-compiled code. The LLVM context and global LLJIT are reused across resets.

pub fn take_last_resource_tracker(&mut self) -> Option<ResourceTracker>

Pops and returns the ResourceTracker for the last committed JIT module.

Each call to jit_function commits a module with its own tracker. The caller takes ownership and is responsible for calling tracker.remove() to free the machine code when it is no longer needed.

The caller must also hold a JitDylibGuard to prevent the owning JITDylib from being recycled before the tracker is removed.

Returns None in AOT mode or if no modules have been committed.

pub fn jit_dylib_guard(&self) -> Arc<JitDylibGuard>

Returns a shared handle that keeps this backend’s JITDylib alive.

The JITDylib will not be cleared or recycled until all JitDylibGuard handles (and the backend itself) are dropped. Callers holding JIT function pointers must retain a guard to prevent the backing code from being freed.