pub struct JitDylibGuard {
pub(crate) global: &'static GlobalOrcJit,
pub(crate) jd: JITDylibRef,
}Expand description
Shared guard that keeps a JITDylib alive.
The JITDylib will not be cleared or returned to the pool until the last
JitDylibGuard is dropped. Runtime callers holding JIT function pointers
must retain a clone of this guard to prevent the code from being freed.
Fields
global: &'static GlobalOrcJitjd: JITDylibRefTrait Implementations