pub struct EvmLlvmBackend {Show 20 fields
pub(crate) cx: &'static Context,
pub(crate) _dh: DiagnosticHandlerGuard,
pub(crate) bcx: Builder<'static>,
pub(crate) module: Module<'static>,
pub(crate) exec_engine: Option<ExecutionEngine<'static>>,
pub(crate) machine: TargetMachine,
pub(crate) ty_void: VoidType<'static>,
pub(crate) ty_ptr: PointerType<'static>,
pub(crate) ty_i1: IntType<'static>,
pub(crate) ty_i8: IntType<'static>,
pub(crate) ty_i32: IntType<'static>,
pub(crate) ty_i64: IntType<'static>,
pub(crate) ty_i256: IntType<'static>,
pub(crate) ty_isize: IntType<'static>,
pub(crate) aot: bool,
pub(crate) debug_assertions: bool,
pub(crate) opt_level: OptimizationLevel,
pub(crate) function_counter: u32,
pub(crate) functions: FxHashMap<u32, (String, FunctionValue<'static>)>,
pub(crate) mapped_symbols: FxHashSet<String>,
}Expand description
The LLVM-based EVM bytecode compiler backend.
Fields
cx: &'static Context_dh: DiagnosticHandlerGuardbcx: Builder<'static>module: Module<'static>exec_engine: Option<ExecutionEngine<'static>>machine: TargetMachinety_void: VoidType<'static>ty_ptr: PointerType<'static>ty_i1: IntType<'static>ty_i8: IntType<'static>ty_i32: IntType<'static>ty_i64: IntType<'static>ty_i256: IntType<'static>ty_isize: IntType<'static>aot: booldebug_assertions: boolopt_level: OptimizationLevelfunction_counter: u32Separate from functions to have always increasing IDs.
functions: FxHashMap<u32, (String, FunctionValue<'static>)>mapped_symbols: FxHashSet<String>Symbol names that have been registered via add_global_mapping in the MCJIT engine.
Used to avoid re-registering builtins when a new module is created after clear_ir.
Implementations
Sourceimpl EvmLlvmBackend
impl EvmLlvmBackend
Sourcepub fn new(aot: bool, opt_level: OptimizationLevel) -> Result<Self>
pub fn new(aot: bool, opt_level: OptimizationLevel) -> Result<Self>
Creates a new LLVM backend for the host machine.
Use new_for_target to create a backend for a specific target.
Sourcepub fn new_for_target(
aot: bool,
opt_level: OptimizationLevel,
target: &Target,
) -> Result<Self>
pub fn new_for_target( aot: bool, opt_level: OptimizationLevel, target: &Target, ) -> Result<Self>
Creates a new LLVM backend for the given target.
pub(crate) fn exec_engine(&self) -> &ExecutionEngine<'static>
pub(crate) fn fn_type( &self, ret: Option<BasicTypeEnum<'static>>, params: &[BasicTypeEnum<'static>], ) -> FunctionType<'static>
pub(crate) fn id_to_name(&self, id: u32) -> &str
pub(crate) fn clear_module(&mut self) -> Result<()>